This is an automated email from the ASF dual-hosted git repository.

mseidel pushed a commit to branch AOO42X
in repository https://gitbox.apache.org/repos/asf/openoffice.git


The following commit(s) were added to refs/heads/AOO42X by this push:
     new d2b267213a Fixed typo (completly -> completely) and many more
d2b267213a is described below

commit d2b267213ab19fb983ed23f27318ab3bf5f2d55d
Author: mseidel <msei...@apache.org>
AuthorDate: Wed Jul 17 16:57:44 2024 +0200

    Fixed typo (completly -> completely) and many more
    
    (cherry picked from commit 870c37922ca0ef0ac9f3f6f409d697814dc73d8a)
---
 main/chart2/source/view/axes/VAxisProperties.cxx   |  4 +--
 .../filter/source/config/tools/split/FCFGSplit.cfg |  4 +--
 main/fpicker/source/office/fpinteraction.cxx       |  2 +-
 main/framework/inc/helper/otasksenumeration.hxx    | 10 +++----
 .../framework/source/fwi/threadhelp/lockhelper.cxx |  2 +-
 .../source/inc/accelerators/presethandler.hxx      | 20 +++++++-------
 .../plugins/sunmajor/pluginlib/vendorbase.hxx      |  2 +-
 main/jvmfwk/source/elements.hxx                    | 31 +++++++++++-----------
 main/l10ntools/source/filter/merge/Merger.java     |  6 ++---
 main/odk/examples/java/Text/HardFormatting.java    | 14 +++++-----
 main/offapi/com/sun/star/document/DocumentInfo.idl |  4 +--
 main/sal/osl/unx/nlsupport.c                       |  6 ++---
 main/sal/osl/w32/dllentry.c                        |  2 +-
 main/sc/source/filter/inc/xehelper.hxx             |  6 ++---
 main/sc/source/filter/inc/xihelper.hxx             |  4 +--
 main/sc/source/filter/xml/XMLTableShapeResizer.cxx |  2 +-
 .../source/presenter/PresenterGeometryHelper.hxx   |  2 +-
 main/sdext/source/presenter/PresenterUIPainter.cxx |  4 +--
 main/svx/source/table/tablemodel.cxx               | 10 +++----
 main/svx/source/table/tablemodel.hxx               |  2 +-
 main/sw/source/ui/docvw/SidebarWin.cxx             |  2 +-
 main/sw/source/ui/index/swuiidxmrk.cxx             |  4 +--
 main/unotools/inc/unotools/historyoptions.hxx      |  8 +++---
 main/uui/source/fltdlg.cxx                         |  4 +--
 main/vcl/inc/vcl/lstbox.h                          |  4 +--
 main/vcl/source/gdi/regband.cxx                    | 22 +++++++--------
 .../source/core/XMLEmbeddedObjectImportContext.cxx |  4 +--
 main/xmloff/source/style/impastp4.cxx              |  2 +-
 28 files changed, 93 insertions(+), 94 deletions(-)

diff --git a/main/chart2/source/view/axes/VAxisProperties.cxx 
b/main/chart2/source/view/axes/VAxisProperties.cxx
index 66122f4280..e89f3ce208 100644
--- a/main/chart2/source/view/axes/VAxisProperties.cxx
+++ b/main/chart2/source/view/axes/VAxisProperties.cxx
@@ -71,8 +71,8 @@ sal_Int32 lcl_calcTickLengthForDepth(sal_Int32 
nDepth,sal_Int32 nTickmarkStyle)
 double lcl_getTickOffset(sal_Int32 nLength,sal_Int32 nTickmarkStyle)
 {
     double fPercent = 0.0; //0<=fPercent<=1
-    //0.0: completly inner
-    //1.0: completly outer
+    //0.0: completely inner
+    //1.0: completely outer
     //0.5: half and half
 
     /*
diff --git a/main/filter/source/config/tools/split/FCFGSplit.cfg 
b/main/filter/source/config/tools/split/FCFGSplit.cfg
index 0e0c2433b8..175c102176 100644
--- a/main/filter/source/config/tools/split/FCFGSplit.cfg
+++ b/main/filter/source/config/tools/split/FCFGSplit.cfg
@@ -31,7 +31,7 @@ xmlfile 
=o:/SRC680/src.m21/officecfg/registry/data/org/openoffice/Office/TypeDet
 informat = 6.0
 
 #------------------------------------------------------
-# must be a system directory, which can be cleared completly
+# must be a system directory, which can be cleared completely
 # and will be used then to generate all results of this
 # program there - means to generate al xcu fragments
 #------------------------------------------------------
@@ -76,7 +76,7 @@ seperate_filters_by_module = false
 #------------------------------------------------------
 # The following defines specify system directories
 # which must be sub directories of "outdir/subdir_filters".
-# Every of these sub dir willl be used to generate
+# Every of these sub dir will be used to generate
 # groups of filter fragments there.
 # Note: These sub directories are used only if
 # "seperate_filters_by_module" is set to true!
diff --git a/main/fpicker/source/office/fpinteraction.cxx 
b/main/fpicker/source/office/fpinteraction.cxx
index 8513de4b7b..8413b845ca 100644
--- a/main/fpicker/source/office/fpinteraction.cxx
+++ b/main/fpicker/source/office/fpinteraction.cxx
@@ -93,7 +93,7 @@ namespace svt
 
         // intercept some interesting interactions
 
-        // The "does not exist" interaction will be suppressed here completly.
+        // The "does not exist" interaction will be suppressed here completely.
         if (m_eInterceptions & OFilePickerInteractionHandler::E_DOESNOTEXIST)
         {
             InteractiveIOException aIoException;
diff --git a/main/framework/inc/helper/otasksenumeration.hxx 
b/main/framework/inc/helper/otasksenumeration.hxx
index c5883a8964..81a4f64ed4 100644
--- a/main/framework/inc/helper/otasksenumeration.hxx
+++ b/main/framework/inc/helper/otasksenumeration.hxx
@@ -125,7 +125,7 @@ class OTasksEnumeration     :       public 
css::lang::XTypeProvider         ,
 
                
/*-****************************************************************************************************//**
                        @short          last chance to release all references 
and free memory
-                       @descr          This method is called, if the 
enumeration is used completly and has no more elements.
+                       @descr          This method is called, if the 
enumeration is used completely and has no more elements.
                                                Then we must destroy our list 
and release all references to other objects.
 
                        @seealso        interface XEventListener
@@ -145,7 +145,7 @@ class OTasksEnumeration     :       public 
css::lang::XTypeProvider         ,
                
/*-****************************************************************************************************//**
                        @short          check count of accessible elements of 
enumeration
                        @descr          You can call this method to get 
information about accessible elements in future.
-                                               Elements you have already 
getted are not accessible!
+                                               Elements you already got are 
not accessible!
 
                        @seealso        interface XEnumeration
 
@@ -154,7 +154,7 @@ class OTasksEnumeration     :       public 
css::lang::XTypeProvider         ,
                                                sal_False = other way
 
                        @onerror        sal_False<BR>
-                                               (List is emtpy and there no 
accessible elements ...)
+                                               (List is empty and there are no 
accessible elements ...)
                
*//*-*****************************************************************************************************/
 
        virtual sal_Bool SAL_CALL hasMoreElements() throw( 
css::uno::RuntimeException );
@@ -166,7 +166,7 @@ class OTasksEnumeration     :       public 
css::lang::XTypeProvider         ,
                        @seealso        interface XEnumeration
 
                        @param          -
-                       @return         A Reference to a task, safed in an 
Any-structure.
+                       @return         A Reference to a task, saved in an 
Any-structure.
 
                        @onerror        If end of enumeration is arrived or 
there are no elements in list => a NoSuchElementException is thrown.
                
*//*-*****************************************************************************************************/
@@ -229,7 +229,7 @@ class OTasksEnumeration     :       public 
css::lang::XTypeProvider         ,
        
//-------------------------------------------------------------------------------------------------------------
 
                
/*-****************************************************************************************************//**
-                       @short          debug-method to check incoming 
parameter of some other mehods of this class
+                       @short          debug-method to check incoming 
parameter of some other methods of this class
                        @descr          The following methods are used to check 
parameters for other methods
                                                of this class. The return value 
is used directly for an ASSERT(...).
 
diff --git a/main/framework/source/fwi/threadhelp/lockhelper.cxx 
b/main/framework/source/fwi/threadhelp/lockhelper.cxx
index 1f8f0a4745..56a9664c30 100644
--- a/main/framework/source/fwi/threadhelp/lockhelper.cxx
+++ b/main/framework/source/fwi/threadhelp/lockhelper.cxx
@@ -383,7 +383,7 @@ void LockHelper::releaseWriteAccess()
                 New readers can work too - new writer are blocked!
                 We use m_eLockType to differ between all possible 
"lock-member"!!!
 
-    @attention  Ignore shareable mutex(!) - because this call never should 
release a lock completly!
+    @attention  Ignore shareable mutex(!) - because this call never should 
release a lock completely!
                 We change a write access to a read access only.
 
     @attention  a) Don't call this method if you are not a writer!
diff --git a/main/framework/source/inc/accelerators/presethandler.hxx 
b/main/framework/source/inc/accelerators/presethandler.hxx
index 0a24da4665..e1a777e572 100644
--- a/main/framework/source/inc/accelerators/presethandler.hxx
+++ b/main/framework/source/inc/accelerators/presethandler.hxx
@@ -95,7 +95,7 @@ class PresetHandler : private ThreadHelpBase // attention! 
Must be the first bas
         /** @short  this handler can provide different
                     types of configuration.
                     
-            @descr  Means: a global or a module dependend
+            @descr  Means: a global or a module dependent
                     or ... configuration.
          */                    
         enum EConfigType
@@ -160,7 +160,7 @@ class PresetHandler : private ThreadHelpBase // attention! 
Must be the first bas
         
         //---------------------------------------
         /** @short  specify the application module for a module
-                    dependend configuration.
+                    dependent configuration.
                     
             @descr  Will be used only, if m_sResourceType is set to
                     "module". Further it must be a valid module identifier
@@ -185,7 +185,7 @@ class PresetHandler : private ThreadHelpBase // attention! 
Must be the first bas
                     where the current configuration set exists.
          
             @descr  Note: If this preset handler works in document mode
-                    this member is meaned relative to the document root ...
+                    this member is meant relative to the document root ...
                     not to the share layer root!
                     
                     Further is defined, that m_xWorkingStorageUser
@@ -313,13 +313,13 @@ class PresetHandler : private ThreadHelpBase // 
attention! Must be the first bas
                     work on a new type of configuration sets.
 
             @param  eConfigType
-                    differ between global or module dependend configuration.
+                    differ between global or module dependent configuration.
                     
             @param  sResourceType
                     differ between menubar/toolbar/accelerator/... 
configuration.
 
             @param  sModule
-                    if sResourceType is set to a module dependend 
configuration,
+                    if sResourceType is set to a module dependent 
configuration,
                     it address the current application module.
                     
             @param  xDocumentRoot
@@ -332,7 +332,7 @@ class PresetHandler : private ThreadHelpBase // attention! 
Must be the first bas
                     in case this configuration supports localized entries,
                     the current locale must be set.
                     
-                    Localzation will be represented as directory structure
+                    Localization will be represented as directory structure
                     of provided presets. Means: you call us with a preset name 
"default";
                     and we use e.g. "/en-US/default.xml" internally.
                     
@@ -355,7 +355,7 @@ class PresetHandler : private ThreadHelpBase // attention! 
Must be the first bas
                     specified target.
                     
             @descr  Means: copy share/.../<preset>.xml user/.../<target>.xml
-                    Note: The target will be overwritten completly or
+                    Note: The target will be overwritten completely or
                     created as new by this operation!
 
             @param  sPreset
@@ -378,7 +378,7 @@ class PresetHandler : private ThreadHelpBase // attention! 
Must be the first bas
                     and return it.
         
             @descr  Note: Because presets resist inside the share
-                    layer, they will be opened readonly everytimes.
+                    layer, they will be opened readonly every time.
 
             @param  sPreset
                     the ALIAS name of an existing preset.
@@ -405,7 +405,7 @@ class PresetHandler : private ThreadHelpBase // attention! 
Must be the first bas
                     
             @param  bCreateIfMissing
                     create target file, if it does not still exist.
-                    Note: That does not means reseting of an existing file!
+                    Note: That does not means resetting of an existing file!
                     
             @return The opened target stream ... or NULL if the target does 
not exists
                     or couldn't be created as new one.
@@ -419,7 +419,7 @@ class PresetHandler : private ThreadHelpBase // attention! 
Must be the first bas
                     
             @descr  We have to call commit on all cached sub storages on the
                     path from the root storage upside down to the working 
storage
-                    (which are not really used, but required to be holded 
alive!).
+                    (which are not really used, but required to be held 
alive!).
          */
         void commitUserChanges();
         
diff --git a/main/jvmfwk/plugins/sunmajor/pluginlib/vendorbase.hxx 
b/main/jvmfwk/plugins/sunmajor/pluginlib/vendorbase.hxx
index ca1af5f3be..cf56c8dd3a 100644
--- a/main/jvmfwk/plugins/sunmajor/pluginlib/vendorbase.hxx
+++ b/main/jvmfwk/plugins/sunmajor/pluginlib/vendorbase.hxx
@@ -119,7 +119,7 @@ public:
 
        @return
        true - the object could completely initialize.
-       false - the object could not completly initialize. In this case
+       false - the object could not completely initialize. In this case
        it will be discarded by the caller.
     */
     virtual bool initialize(
diff --git a/main/jvmfwk/source/elements.hxx b/main/jvmfwk/source/elements.hxx
index 3616469953..9037c1c355 100644
--- a/main/jvmfwk/source/elements.hxx
+++ b/main/jvmfwk/source/elements.hxx
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,19 +7,18 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
-
 #if !defined INCLUDED_JVMFWK_ELEMENTS_HXX
 #define INCLUDED_JVMFWK_ELEMENTS_HXX
 
@@ -94,7 +93,7 @@ public:
         an no further elements are read.
      */
     void loadFromNode(xmlDoc * pDoc,xmlNode * pJavaInfo);
-    /** The attribut nil will be set to false. The function gets the value
+    /** The attribute nil will be set to false. The function gets the value
         javaSettings/updated from the javavendors.xml and writes it to
         javaInfo@vendorUpdate in javasettings.xml
      */
@@ -132,7 +131,7 @@ private:
         (UNO_JAVA_JFW_USER_DATA, UNO_JAVA_JFW_SHARED_DATA,
         UNO_JAVA_JFW_INSTALL_DATA) and m_layer, unless the file already exists
         (see createSettingsDocument).
-        
+
         @return
         JFW_E_CONFIG_READWRITE
     */
@@ -141,7 +140,7 @@ private:
     /** helper function for prepareSettingsDocument.
     */
     void createSettingsDocument() const;
-    
+
     /** returns the system path to the data file which is to be used. The value
         depends on the member m_layer and the bootstrap parameters 
UNO_JAVA_JFW_USER_DATA,
         UNO_JAVA_JFW_SHARED_DATA and UNO_JAVA_JFW_INSTALL_DATA which this may 
be.
@@ -149,7 +148,7 @@ private:
     ::rtl::OString getSettingsPath() const;
 
     /** returns the file URL to the data file which is to be used. See 
getSettingsPath.
-    */  
+    */
     ::rtl::OUString getSettingsURL() const;
 
     /** Verifies if the respective settings file exist. In case 
UNO_JAVA_JFW_INSTALL_DATA
@@ -157,7 +156,7 @@ private:
         exist and wipe its contents. Then still FILE_DOES_NOT_EXIST is 
returned.
      */
     jfw::FileStatus checkSettingsFileStatus() const;
-    
+
     /** Determines the layer for which the instance the loads and writes the
         data.
     */
@@ -205,7 +204,7 @@ private:
         JFW_E_NO_SELECT. So it looped. (see issue i114509)
 
         NFS server and NFS client should have the same time. It is common
-        practise to enforce this in networks. We actually should not work
+        practice to enforce this in networks. We actually should not work
         around a malconfigured network. We must however, make sure that we do
         not loop. Maybe a better approach is, that:
         - assume that mtime and system time are reliable
@@ -287,8 +286,8 @@ public:
 };
 
 /** merges the settings for shared, user and installation during construction.
-    The class uses a simple merge mechanism for the javasettings.xml files in 
share and 
-    user. The following elements completly overwrite the corresponding 
elements 
+    The class uses a simple merge mechanism for the javasettings.xml files in 
share and
+    user. The following elements completely overwrite the corresponding 
elements
     from share:
     /java/enabled
     /java/userClassPath
@@ -322,7 +321,7 @@ private:
     ::std::vector< ::rtl::OUString> m_vmParams;
 
     ::std::vector< ::rtl::OUString> m_JRELocations;
-    
+
     CNodeJavaInfo m_javaInfo;
 
 public:
@@ -380,7 +379,7 @@ public:
     ~VersionInfo();
 
     void addExcludeVersion(const ::rtl::OUString& sVersion);
-    
+
     ::rtl::OUString sMinVersion;
     ::rtl::OUString sMaxVersion;
 
@@ -388,7 +387,7 @@ public:
         does not need to release the strings.
         The array exists as long as this object exists.
     */
-    
+
     rtl_uString** getExcludeVersions();
     sal_Int32 getExcludeVersionSize();
 };
diff --git a/main/l10ntools/source/filter/merge/Merger.java 
b/main/l10ntools/source/filter/merge/Merger.java
index 981f05ce86..c7a2a77322 100644
--- a/main/l10ntools/source/filter/merge/Merger.java
+++ b/main/l10ntools/source/filter/merge/Merger.java
@@ -269,7 +269,7 @@ public class Merger
 
         // Attention!
         // If the package seem to be empty, it make no sense to generate a 
corresponding
-        // xml file. We should suppress writing of this file on disk completly 
...
+        // xml file. We should suppress writing of this file on disk 
completely ...
         if (nItemCount < 1)
         {
             m_aLog.setWarning("Package is empty and will not result into a xml 
file on disk!? Please check configuration file.");
@@ -278,7 +278,7 @@ public class Merger
         m_aLog.setGlobalInfo("package contains "+nItemCount+" items");
 
         java.io.File aPackage = new File(sPackage);
-        m_aLog.setGlobalInfo("write temp package \""+aPackage.getPath()); // 
TODO encoding must be readed from the configuration
+        m_aLog.setGlobalInfo("write temp package \""+aPackage.getPath()); // 
TODO encoding must be read from the configuration
         FileHelper.writeEncodedBufferToFile(aPackage, "UTF-8", false, 
sBuffer); // check for success is done inside this method!
     }
 
@@ -308,7 +308,7 @@ public class Merger
         // special mode for generating language packs.
         // In such case we must live with some missing fragment files.
         // Reason behind; Not all filters are really localized.
-        // But we dont use a different fragment list. We try to locate
+        // But we don't use a different fragment list. We try to locate
         // any fragment file in its language-pack version ...
         boolean bHandleLanguagePacks = m_aCfg.getBoolean(PROP_LANGUAGEPACK, 
false);
         boolean bDebug               = m_aCfg.getBoolean(PROP_DEBUG       , 
false);
diff --git a/main/offapi/com/sun/star/document/DocumentInfo.idl 
b/main/offapi/com/sun/star/document/DocumentInfo.idl
index 85af2a9523..16f35bfc54 100644
--- a/main/offapi/com/sun/star/document/DocumentInfo.idl
+++ b/main/offapi/com/sun/star/document/DocumentInfo.idl
@@ -64,8 +64,8 @@
 
     <p>
     Contrary to the service <type>StandaloneDocumentInfo</type> the document - 
which
-    contains such informations - must be loaded completly. As a result of that 
this
-    DocumengInfo service is available on an open document via the interface
+    contains such informations - must be loaded completely. As a result of 
that this
+    DocumentInfo service is available on an open document via the interface
     <type>XDocumentInfoSupplier</type> only.
     </p>
 
diff --git a/main/sal/osl/unx/nlsupport.c b/main/sal/osl/unx/nlsupport.c
index 3945d5cb27..d889d9cddf 100644
--- a/main/sal/osl/unx/nlsupport.c
+++ b/main/sal/osl/unx/nlsupport.c
@@ -250,8 +250,8 @@ static rtl_Locale * _parse_locale( const char * locale )
 /*
  * _nl_language_list[] is an array list of supported encodings. Because
  * we are using a binary search, the list has to be in ascending order.
- * We are comparing the encodings case insensitiv, so the list has
- * to be completly upper- , or lowercase.
+ * We are comparing the encodings case insensitive, so the list has
+ * to be completely upper- , or lowercase.
  */
 
 #if defined(SOLARIS)
@@ -801,7 +801,7 @@ rtl_TextEncoding osl_getTextEncodingFromLocale( rtl_Locale 
* pLocale )
         {
             const unsigned int members = sizeof( _iso_language_list ) / 
sizeof( _pair );
 
-            /* iso lang codes have 2 charaters */
+            /* iso lang codes have 2 characters */
             locale_buf[2] = '\0';
 
             language = _pair_search( locale_buf, _iso_language_list, members);
diff --git a/main/sal/osl/w32/dllentry.c b/main/sal/osl/w32/dllentry.c
index 8d9e4334fe..746eb7e9f4 100644
--- a/main/sal/osl/w32/dllentry.c
+++ b/main/sal/osl/w32/dllentry.c
@@ -244,7 +244,7 @@ void do_cleanup( void )
                        ntdll is on the stack. No chance to find the reason for 
the
                        corrupted heap if so.
 
-                       So annoying the user with a crash report is completly 
useless.
+                       So annoying the user with a crash report is completely 
useless.
 
                        */
 
diff --git a/main/sc/source/filter/inc/xehelper.hxx 
b/main/sc/source/filter/inc/xehelper.hxx
index 9f5a99f8eb..c559b1ead3 100644
--- a/main/sc/source/filter/inc/xehelper.hxx
+++ b/main/sc/source/filter/inc/xehelper.hxx
@@ -35,7 +35,7 @@ class ScfProgressBar;
 /** The main progress bar for the export filter.
 
     This class encapsulates creation and initialization of sub progress
-    segments. The Activate***Segment() functions activate a specific segement
+    segments. The Activate***Segment() functions activate a specific segment
     of the main progress bar. The implementation of these functions contain the
     calculation of the needed size of the segment. Following calls of the
     Progress() function increase the currently activated sub segment.
@@ -150,7 +150,7 @@ public:
 //UNUSED2008-05      @param bWarn  true = Sets the internal flag that produces 
a warning box
 //UNUSED2008-05          after loading/saving the file, if the cell range list 
contains at
 //UNUSED2008-05          least one invalid range.
-//UNUSED2008-05      @return  true = Cell range list in rScRanges is completly 
valid. */
+//UNUSED2008-05      @return  true = Cell range list in rScRanges is 
completely valid. */
 //UNUSED2008-05  bool                CheckRangeList( const ScRangeList& 
rScRanges, bool bWarn );
 
     /** Checks and eventually crops the cell ranges to valid dimensions.
@@ -349,7 +349,7 @@ class EditEngine;
 /** Converts edit engine text objects to an Excel header/footer string.
     @descr  Header/footer content is divided into three parts: Left, center and
     right portion. All formatting information will be encoded in the Excel 
string
-    using special character seuences. A control sequence starts with the 
ampersand
+    using special character sequences. A control sequence starts with the 
ampersand
     character.
 
     Supported control sequences:
diff --git a/main/sc/source/filter/inc/xihelper.hxx 
b/main/sc/source/filter/inc/xihelper.hxx
index 9810990b8e..c415927668 100644
--- a/main/sc/source/filter/inc/xihelper.hxx
+++ b/main/sc/source/filter/inc/xihelper.hxx
@@ -98,7 +98,7 @@ public:
 //UNUSED2009-05     @param bWarn  true = Sets the internal flag that produces 
a warning box
 //UNUSED2009-05         after loading/saving the file, if the cell range list 
contains at
 //UNUSED2009-05         least one invalid range.
-//UNUSED2009-05     @return  true = Cell range list in rScRanges is completly 
valid. */
+//UNUSED2009-05     @return  true = Cell range list in rScRanges is completely 
valid. */
 //UNUSED2009-05 bool                CheckRangeList( const XclRangeList& 
rXclRanges, bool bWarn );
 
     /** Converts the passed Excel cell range list to a Calc cell range list.
@@ -157,7 +157,7 @@ struct XclFontData;
 /** Converts an Excel header/footer string into three edit engine text objects.
     @descr  Header/footer content is divided into three parts: Left, center and
     right portion. All formatting information is encoded in the Excel string
-    using special character seuences. A control sequence starts with the 
ampersand
+    using special character sequences. A control sequence starts with the 
ampersand
     character.
 
     Supported control sequences:
diff --git a/main/sc/source/filter/xml/XMLTableShapeResizer.cxx 
b/main/sc/source/filter/xml/XMLTableShapeResizer.cxx
index 890a788ea0..99b07d24df 100644
--- a/main/sc/source/filter/xml/XMLTableShapeResizer.cxx
+++ b/main/sc/source/filter/xml/XMLTableShapeResizer.cxx
@@ -96,7 +96,7 @@ void ScMyShapeResizer::CreateChartListener(ScDocument* pDoc,
 
         //for loading binary files e.g.
         //if we have the flat filter we need to set the dirty flag thus the 
visible charts get repainted
-        //otherwise the charts keep their first visual representation which 
was created at a moment where the calc itself was not loaded completly and is 
incorect therefor
+        //otherwise the charts keep their first visual representation which 
was created at a moment where the calc itself was not loaded completely and is 
incorrect therefor
         if( (rImport.getImportFlags() & IMPORT_ALL) == IMPORT_ALL )
             pCL->SetDirty( sal_True );
         else
diff --git a/main/sdext/source/presenter/PresenterGeometryHelper.hxx 
b/main/sdext/source/presenter/PresenterGeometryHelper.hxx
index 4bd8b6893a..0963b32f4f 100644
--- a/main/sdext/source/presenter/PresenterGeometryHelper.hxx
+++ b/main/sdext/source/presenter/PresenterGeometryHelper.hxx
@@ -82,7 +82,7 @@ public:
         const css::geometry::RealRectangle2D& rBox,
         const css::geometry::RealPoint2D& rPoint);
 
-    /** Return whether rBox1 is completly inside rBox2.
+    /** Return whether rBox1 is completely inside rBox2.
     */
     static bool IsInside (
         const css::awt::Rectangle& rBox1,
diff --git a/main/sdext/source/presenter/PresenterUIPainter.cxx 
b/main/sdext/source/presenter/PresenterUIPainter.cxx
index a38db25bcf..1617ea8586 100644
--- a/main/sdext/source/presenter/PresenterUIPainter.cxx
+++ b/main/sdext/source/presenter/PresenterUIPainter.cxx
@@ -47,7 +47,7 @@ void PresenterUIPainter::PaintHorizontalBitmapComposite (
 {
     if (PresenterGeometryHelper::AreRectanglesDisjoint(rRepaintBox, 
rBoundingBox))
     {
-        // The bounding box lies completly outside the repaint area.
+        // The bounding box lies completely outside the repaint area.
         // Nothing has to be repainted.
         return;
     }
@@ -152,7 +152,7 @@ void PresenterUIPainter::PaintVerticalBitmapComposite (
 {
     if (PresenterGeometryHelper::AreRectanglesDisjoint(rRepaintBox, 
rBoundingBox))
     {
-        // The bounding box lies completly outside the repaint area.
+        // The bounding box lies completely outside the repaint area.
         // Nothing has to be repainted.
         return;
     }
diff --git a/main/svx/source/table/tablemodel.cxx 
b/main/svx/source/table/tablemodel.cxx
index db31438b24..c5ad43ba7e 100644
--- a/main/svx/source/table/tablemodel.cxx
+++ b/main/svx/source/table/tablemodel.cxx
@@ -817,7 +817,7 @@ void TableModel::removeColumns( sal_Int32 nIndex, sal_Int32 
nCount )
                {
                        TableModelNotifyGuard aGuard( this );
 
-                       // clip removed columns to columns actually avalaible
+                       // clip removed columns to columns actually available
                        if( (nIndex + nCount) > nColCount )
                                nCount = nColCount - nIndex;
 
@@ -885,7 +885,7 @@ void TableModel::removeColumns( sal_Int32 nIndex, sal_Int32 
nCount )
                                        }
                                        else if( nColSpan > (nIndex - nCol) )
                                        {
-                                               // current cells spans inside 
the removed columns, so adjust                                    
+                                               // current cells spans inside 
the removed columns, so adjust
                                                const sal_Int32 nRemove = 
::std::min( nCount, nCol + nColSpan - nIndex );
                                                if( bUndo )
                                                        xCell->AddUndo();
@@ -993,7 +993,7 @@ void TableModel::removeRows( sal_Int32 nIndex, sal_Int32 
nCount )
                {
                        TableModelNotifyGuard aGuard( this );
 
-                       // clip removed rows to rows actually avalaible
+                       // clip removed rows to rows actually available
                        if( (nIndex + nCount) > nRowCount )
                                nCount = nRowCount - nIndex;
 
@@ -1046,7 +1046,7 @@ void TableModel::removeRows( sal_Int32 nIndex, sal_Int32 
nCount )
                                        }
                                        else if( nRowSpan > (nIndex - nRow) )
                                        {
-                                               // current cells spans inside 
the removed rows, so adjust                                       
+                                               // current cells spans inside 
the removed rows, so adjust
                                                const sal_Int32 nRemove = 
::std::min( nCount, nRow + nRowSpan - nIndex );
                                                if( bUndo )
                                                        xCell->AddUndo();
@@ -1096,7 +1096,7 @@ TableColumnRef TableModel::getColumn( sal_Int32 nColumn ) 
const throw (IndexOutO
 
 // 
-----------------------------------------------------------------------------
 
-/** deletes rows and columns that are completly merged. Must be called between 
BegUndo/EndUndo! */
+/** deletes rows and columns that are completely merged. Must be called 
between BegUndo/EndUndo! */
 void TableModel::optimize()
 {
        TableModelNotifyGuard aGuard( this );
diff --git a/main/svx/source/table/tablemodel.hxx 
b/main/svx/source/table/tablemodel.hxx
index 6a1cfcfeb7..27c4deea2a 100644
--- a/main/svx/source/table/tablemodel.hxx
+++ b/main/svx/source/table/tablemodel.hxx
@@ -86,7 +86,7 @@ public:
 
        SdrTableObj* getSdrTableObj() const { return mpTableObj; }
 
-       /** deletes rows and columns that are completly merged. Must be called 
between BegUndo/EndUndo! */
+       /** deletes rows and columns that are completely merged. Must be called 
between BegUndo/EndUndo! */
        void optimize();
 
     /// merges the cell at the given position with the given span
diff --git a/main/sw/source/ui/docvw/SidebarWin.cxx 
b/main/sw/source/ui/docvw/SidebarWin.cxx
index e297ab6340..2b2cdd87e9 100644
--- a/main/sw/source/ui/docvw/SidebarWin.cxx
+++ b/main/sw/source/ui/docvw/SidebarWin.cxx
@@ -1432,7 +1432,7 @@ void SwRedComment::ActivatePostIt()
 
     // do we want the redline selected?
     // otherwise, SwRedComment::ActivatePostIt() as well as 
SwRedComment::DeactivatePostIt()
-    // can be thrown out completly
+    // can be thrown out completely
     DocView()->GetDocShell()->GetWrtShell()->GotoRedline(
         
DocView()->GetDocShell()->GetWrtShell()->FindRedlineOfData(pRedline->GetRedlineData()),true);
 }
diff --git a/main/sw/source/ui/index/swuiidxmrk.cxx 
b/main/sw/source/ui/index/swuiidxmrk.cxx
index 032a089e3d..2d5862767a 100644
--- a/main/sw/source/ui/index/swuiidxmrk.cxx
+++ b/main/sw/source/ui/index/swuiidxmrk.cxx
@@ -1030,7 +1030,7 @@ IMPL_LINK( SwIndexMarkDlg, KeyDCBModifyHdl, ComboBox *, 
pBox )
                {
                        if(pBox->IsInDropDown())
                        {
-                               //reset bPhoneticED1_ChangedByUser if a 
completly new string is selected
+                               //reset bPhoneticED1_ChangedByUser if a 
completely new string is selected
                                bPhoneticED1_ChangedByUser = sal_False;
                        }
                        if(!bPhoneticED1_ChangedByUser)
@@ -1050,7 +1050,7 @@ IMPL_LINK( SwIndexMarkDlg, KeyDCBModifyHdl, ComboBox *, 
pBox )
                {
                        if(pBox->IsInDropDown())
                        {
-                               //reset bPhoneticED1_ChangedByUser if a 
completly new string is selected
+                               //reset bPhoneticED1_ChangedByUser if a 
completely new string is selected
                                bPhoneticED2_ChangedByUser = sal_False;
                        }
                        if(!bPhoneticED2_ChangedByUser)
diff --git a/main/unotools/inc/unotools/historyoptions.hxx 
b/main/unotools/inc/unotools/historyoptions.hxx
index 7b98654076..e3c0ca9e7e 100644
--- a/main/unotools/inc/unotools/historyoptions.hxx
+++ b/main/unotools/inc/unotools/historyoptions.hxx
@@ -148,7 +148,7 @@ class UNOTOOLS_DLLPUBLIC SvtHistoryOptions: public 
utl::detail::Options
                void            SetSize( EHistoryType eHistory, sal_uInt32 
nSize        )               ;
 
                
/*-****************************************************************************************************//**
-                       @short          clear complete sepcified list
+                       @short          clear complete specified list
                        @descr          Call this methods to clear the whole 
list. After that GetItemCount() will return 0 ...
                                                but GetSize() will return the 
old value!
 
@@ -163,8 +163,8 @@ class UNOTOOLS_DLLPUBLIC SvtHistoryOptions: public 
utl::detail::Options
                void Clear( EHistoryType eHistory );
 
                
/*-****************************************************************************************************//**
-                       @short          return complete sepcified list
-                       @descr          If you will show the whole list call 
this method to get it completly.
+                       @short          return complete specified list
+                       @descr          If you will show the whole list call 
this method to get it completely.
 
                        @seealso        -
 
@@ -181,7 +181,7 @@ class UNOTOOLS_DLLPUBLIC SvtHistoryOptions: public 
utl::detail::Options
                        @descr          You can append items to a list only - 
removing isn't allowed for a special item!
                                                The oldest entry is deleted 
automatically if max size arrived or you can call Clear() ...
                                                It exist two different overload 
methods to do this.
-                                               One for user which have an 
complete history item and another one for uncompletly data sets!
+                                               One for user which have an 
complete history item and another one for incompletely data sets!
 
                        @seealso        method SetSize()
                        @seealso        method Clear()
diff --git a/main/uui/source/fltdlg.cxx b/main/uui/source/fltdlg.cxx
index d6f2911ed0..47a8398507 100644
--- a/main/uui/source/fltdlg.cxx
+++ b/main/uui/source/fltdlg.cxx
@@ -63,7 +63,7 @@ namespace uui
     @seealso    method SetURL()
 
     @param      "pParentWindow"  , parent window for dialog
-    @param      "pResMgr"        , ressource manager
+    @param      "pResMgr"        , resource manager
     @return     -
 
     @onerror    -
@@ -115,7 +115,7 @@ void FilterDialog::SetURL( const String& sURL )
     @param      "pFilterNames", pointer to list of filter names, which should 
be used for later operations.
     @return     -
 
-    @onerror    We clear list box and forget our currently set filter 
informations completly!
+    @onerror    We clear list box and forget our currently set filter 
informations completely!
     @threadsafe no
 
*//*-*************************************************************************************************************/
 void FilterDialog::ChangeFilters( const FilterNameList* pFilterNames )
diff --git a/main/vcl/inc/vcl/lstbox.h b/main/vcl/inc/vcl/lstbox.h
index 586eb7ef86..1f7af14035 100644
--- a/main/vcl/inc/vcl/lstbox.h
+++ b/main/vcl/inc/vcl/lstbox.h
@@ -36,10 +36,10 @@
 // and GetEntryFlags() methods
 
 // !! Do not use these flags for user data as they are reserved      !!
-// !! to change the internal behaviour of the ListBox implementation !!
+// !! to change the internal behavior of the ListBox implementation !!
 // !! for specific entries.                                                    
                                 !!
 
-/** this flag disables a selection of an entry completly. It is not
+/** this flag disables a selection of an entry completely. It is not
        possible to select such entries either from the user interface
        nor from the ListBox methods. Cursor traveling is handled correctly.
        This flag can be used to add titles to a ListBox.
diff --git a/main/vcl/source/gdi/regband.cxx b/main/vcl/source/gdi/regband.cxx
index 4dd8bb5a67..ad1dd64829 100644
--- a/main/vcl/source/gdi/regband.cxx
+++ b/main/vcl/source/gdi/regband.cxx
@@ -278,7 +278,7 @@ bool ImplRegionBand::InsertPoint( long nX, long nLineId,
        pLastTestedRegionBandPoint = NULL;
        while ( pRegionBandPoint )
        {
-               // new point completly left? -> insert as first point
+               // new point completely left? -> insert as first point
                if ( nX <= pRegionBandPoint->mnX )
                {
                        pNewRegionBandPoint                                     
= new ImplRegionBandPoint;
@@ -345,7 +345,7 @@ void ImplRegionBand::ScaleX( double fHorzScale )
 
 // -----------------------------------------------------------------------
 //
-// combine overlaping sparations
+// combine overlapping separations
 
 bool ImplRegionBand::OptimizeBand()
 {
@@ -366,7 +366,7 @@ bool ImplRegionBand::OptimizeBand()
                        continue;
                }
 
-               // overlaping separations? -> combine!
+               // overlapping separations? -> combine!
                if ( pSep->mpNextSep )
                {
                        if ( (pSep->mnXRight+1) >= pSep->mpNextSep->mnXLeft )
@@ -415,7 +415,7 @@ void ImplRegionBand::Union( long nXLeft, long nXRight )
                if ( (nXLeft >= pSep->mnXLeft) && (nXRight <= pSep->mnXRight) )
                        return;
 
-               // new separation completly left? -> new separation!
+               // new separation completely left? -> new separation!
                if ( nXRight < pSep->mnXLeft )
                {
                        pNewSep                         = new ImplRegionBandSep;
@@ -431,11 +431,11 @@ void ImplRegionBand::Union( long nXLeft, long nXRight )
                        break;
                }
 
-               // new separation overlaping from left? -> extend boundary
+               // new separation overlapping from left? -> extend boundary
                if ( (nXRight >= pSep->mnXLeft) && (nXLeft <= pSep->mnXLeft) )
                        pSep->mnXLeft = nXLeft;
 
-               // new separation overlaping from right? -> extend boundary
+               // new separation overlapping from right? -> extend boundary
                if ( (nXLeft <= pSep->mnXRight) && (nXRight > pSep->mnXRight) )
                {
                        pSep->mnXRight = nXRight;
@@ -479,18 +479,18 @@ void ImplRegionBand::Intersect( long nXLeft, long nXRight 
)
        ImplRegionBandSep* pSep = mpFirstSep;
        while ( pSep )
        {
-               // new separation completly outside? -> remove separation
+               // new separation completely outside? -> remove separation
                if ( (nXRight < pSep->mnXLeft) || (nXLeft > pSep->mnXRight) )
                        // will be removed from the optimizer
                        pSep->mbRemoved = true;
 
-               // new separation overlaping from left? -> reduce right boundary
+               // new separation overlapping from left? -> reduce right 
boundary
                if ( (nXLeft <= pSep->mnXLeft) &&
                         (nXRight <= pSep->mnXRight) &&
                         (nXRight >= pSep->mnXLeft) )
                        pSep->mnXRight = nXRight;
 
-               // new separation overlaping from right? -> reduce right 
boundary
+               // new separation overlapping from right? -> reduce right 
boundary
                if ( (nXLeft >= pSep->mnXLeft) &&
                         (nXLeft <= pSep->mnXRight) &&
                         (nXRight >= pSep->mnXRight) )
@@ -538,7 +538,7 @@ void ImplRegionBand::Exclude( long nXLeft, long nXRight )
                        bSepProcessed = true;
                }
 
-               // new separation overlaping from left? -> reduce boundary
+               // new separation overlapping from left? -> reduce boundary
                if ( !bSepProcessed )
                {
                        if ( (nXRight >= pSep->mnXLeft) && (nXLeft <= 
pSep->mnXLeft) )
@@ -548,7 +548,7 @@ void ImplRegionBand::Exclude( long nXLeft, long nXRight )
                        }
                }
 
-               // new separation overlaping from right? -> reduce boundary
+               // new separation overlapping from right? -> reduce boundary
                if ( !bSepProcessed )
                {
                        if ( (nXLeft <= pSep->mnXRight) && (nXRight > 
pSep->mnXRight) )
diff --git a/main/xmloff/source/core/XMLEmbeddedObjectImportContext.cxx 
b/main/xmloff/source/core/XMLEmbeddedObjectImportContext.cxx
index 18a8eab64e..83b94c1866 100644
--- a/main/xmloff/source/core/XMLEmbeddedObjectImportContext.cxx
+++ b/main/xmloff/source/core/XMLEmbeddedObjectImportContext.cxx
@@ -299,7 +299,7 @@ void XMLEmbeddedObjectImportContext::StartElement(
        if( xHandler.is() )
        {
                xHandler->startDocument();
-               // #i34042: copy namepspace declarations
+               // #i34042: copy namespace declarations
                SvXMLAttributeList *pAttrList = new SvXMLAttributeList( 
rAttrList );
                Reference< XAttributeList > xAttrList( pAttrList );
                const SvXMLNamespaceMap& rNamespaceMap = 
GetImport().GetNamespaceMap();
@@ -364,7 +364,7 @@ void XMLEmbeddedObjectImportContext::EndElement()
 
 
 //             // reset modifies state for the object since it has been 
imported
-//             // completly and therfor hasn't been modified.
+//             // completely and therefor hasn't been modified.
 //             Reference < XModifiable > xModifiable( xComp, UNO_QUERY );
 //             if( xModifiable.is() )
 //             {
diff --git a/main/xmloff/source/style/impastp4.cxx 
b/main/xmloff/source/style/impastp4.cxx
index 9faf0ef5a9..de545c6502 100644
--- a/main/xmloff/source/style/impastp4.cxx
+++ b/main/xmloff/source/style/impastp4.cxx
@@ -346,7 +346,7 @@ OUString SvXMLAutoStylePoolP_Impl::FindAndRemoveCached( 
sal_Int32 nFamily ) cons
                DBG_ASSERT( pFamily->pCache, "family doesn't have a cache" );
 
                // The cache may be empty already. This happens if it was filled
-               // completly.
+               // completely.
                if( pFamily->pCache && pFamily->pCache->Count() )
                {
                        OUString *pName = pFamily->pCache->Remove( 0UL );


Reply via email to
diff --git a/main/odk/examples/java/Text/HardFormatting.java 
b/main/odk/examples/java/Text/HardFormatting.java
index 9f5d9f49c1..911ab54dce 100644
--- a/main/odk/examples/java/Text/HardFormatting.java
+++ b/main/odk/examples/java/Text/HardFormatting.java
@@ -38,7 +38,7 @@ public class HardFormatting {
     public static void main(String args[]) {
         // You need the desktop to create a document
         // The getDesktop method does the UNO bootstrapping, gets the
-        // remote servie manager and the desktop object.
+        // remote service manager and the desktop object.
         com.sun.star.frame.XDesktop xDesktop = null;
         xDesktop = getDesktop();
         
@@ -54,7 +54,7 @@ public class HardFormatting {
             
             String sMyText = "A very short paragraph for illustration only";
             
-            // you can travel with the cursor throught the text document.
+            // you can travel with the cursor through the text document.
             // you travel only at the model, not at the view. The cursor that 
you can
             // see on the document doesn't change the position
             com.sun.star.text.XTextCursor xTextCursor = null;
@@ -77,7 +77,7 @@ public class HardFormatting {
                 UnoRuntime.queryInterface(
                     com.sun.star.beans.XPropertySet.class, xTextRange);
             
-            // create a paragraph cursor to travel throught the paragraphs
+            // create a paragraph cursor to travel through the paragraphs
             com.sun.star.text.XParagraphCursor xParagraphCursor = null;
             xParagraphCursor = (com.sun.star.text.XParagraphCursor)
                 UnoRuntime.queryInterface(
@@ -124,7 +124,7 @@ public class HardFormatting {
                 + xPropertySet.getPropertyValue("CharWeight").toString() );
             
             // the PropertyState contains information where the attribute is 
set,
             // is a text part hard formated or not.
             com.sun.star.beans.XPropertyState xPropertyState = null;
             xPropertyState = (com.sun.star.beans.XPropertyState)
                 UnoRuntime.queryInterface(
@@ -170,21 +170,21 @@ public class HardFormatting {
             case com.sun.star.beans.PropertyState.DIRECT_VALUE_value:  {
                 System.out.println( "-> The selection '"
                                     + xWordCursor.getString()
-                                    + "' completly hard formated" );
+                                    + "' completely hard formatted" );
                 break;
             }
             
             case com.sun.star.beans.PropertyState.DEFAULT_VALUE_value: {
                 System.out.println( "-> The selection '"
                                     + xWordCursor.getString()
-                                    + "' isn't hard formated" );
+                                    + "' isn't hard formatted" );
                 break;
             }
             
             case com.sun.star.beans.PropertyState.AMBIGUOUS_VALUE_value: {
                 System.out.println( "-> The selection '"
                                     + xWordCursor.getString()
-                                    + "' isn't completly hard formated" );
+                                    + "' isn't completely hard formatted" );
                 break;
             }
             
@@ -124,7 +124,7 @@ public class HardFormatting {
             // the PropertyState contains information where the attribute is 
set,
-            // is a text part hard formated or not.
+            // is a text part hard formatted or not.
             com.sun.star.beans.XPropertyState xPropertyState = null;
             xPropertyState = (com.sun.star.beans.XPropertyState)